@@ -1,10 +1,10 @@
 from json import dumps
-from typing import Dict, Optional, Any, final
+from typing import Any, Dict, Optional
 from uuid import uuid4
 
 
 def raise_(err: BaseException) -> BaseException:
-    raise err
+    raise err  # pragma: no cover
 
 
 class BaseError(Exception):
@@ -14,27 +14,33 @@ class BaseError(Exception):
     _detail: str
     _meta: Dict[str, Any]
 
-    def __init__(self, *args, **kwargs) -> None:
+    def __init__(self, *args, **kwargs) -> None:  # type: ignore
         super().__init__(*args)
         self._id = kwargs.get('id', str(uuid4()))
         self._code = kwargs.get('code', self._code)
         self._title = kwargs.get('title', self._title)
         self._detail = dumps(kwargs.get('detail', {}))
         self._meta = kwargs.get('meta', {})
-        if self._has_a_system_exit_exception():
-            raise SystemExit(self._meta.get('exception'))
+        self.ensure_there_is_not_a_system_exit()
 
     @classmethod
-    def create(cls, detail: Optional[Dict[str, Any]] = None, meta: Optional[Dict[str, Any]] = None) -> 'BaseError':
-        return cls(id=str(uuid4()), detail=detail or {}, meta=meta or {})
-
-    def _has_a_system_exit_exception(self) -> bool:
-        return self._meta.get('exception_type', None) is SystemExit
+    def create(
+        cls,
+        detail: Optional[Dict[str, Any]] = None,
+        meta: Optional[Dict[str, Any]] = None,
+        **kwargs: Dict[str, Any],
+    ) -> 'BaseError':
+        return cls(detail=detail or {}, meta=meta or {}, **kwargs)
 
     def with_exception(self, err: BaseException) -> 'BaseError':
         self._meta.update({'exception': str(err), 'exception_type': str(type(err))})
+        self.ensure_there_is_not_a_system_exit()
         return self
 
+    def ensure_there_is_not_a_system_exit(self) -> None:
+        if self._meta.get('exception_type', None) == '<class \'SystemExit\'>':
+            raise SystemExit(self._meta.get('exception'))
+
     def id(self) -> str:
         return self._id
 
@@ -51,13 +57,16 @@ class BaseError(Exception):
         return self._meta
 
     def __str__(self) -> str:
-        return dumps({
-            'id': self._id,
-            'code': self._code,
-            'title': self._title,
-            'detail': self._detail,
-            'meta': self._meta,
-        }, indent=2)
+        return dumps(
+            {
+                'id': self._id,
+                'code': self._code,
+                'title': self._title,
+                'detail': self._detail,
+                'meta': self._meta,
+            },
+            indent=2,
+        )
 
 
 class NotFoundError(BaseError):
@@ -66,24 +75,33 @@ class NotFoundError(BaseError):
 
 
 class ConflictError(BaseError):
-    _code = 'conflict',
-    _title = 'Conflict',
+    _code = 'conflict'
+    _title = 'Conflict'
 
 
 class BadRequestError(BaseError):
-    _code = 'bad_request',
-    _title = 'Bad Request',
+    _code = 'bad_request'
+    _title = 'Bad Request'
+
+
+class UnauthorizedError(BaseError):
+    _code = 'unauthorized'
+    _title = 'Unauthorized'
+
+
+class ForbiddenError(BaseError):
+    _code = 'forbidden'
+    _title = 'Forbidden'
 
 
-@final
 class UnknownError(BaseError):
-    _code = 'unknown',
-    _title = 'Unknown error',
+    _code = 'unknown'
+    _title = 'Unknown error'
 
 
 class IdInvalidError(ConflictError):
-    _code = 'id_invalid',
-    _title = 'Invalid id',
+    _code = 'id_invalid'
+    _title = 'Invalid id'
 
 
 class TimestampInvalidError(ConflictError):
