@@ -3,10 +3,10 @@ from os import getenv
 from typing import Any, Dict, Optional, Type, TypeVar, Union
 
 
-def get_env(key: str, default: Optional[str] = None) -> str:  # pragma: no cover
+def get_env(key: str, default: Optional[str] = None, cast_default_to_str: bool = True) -> Optional[str]:
     """Get an environment variable, return default if it is empty or doesn't exist."""
     value = getenv(key, default)
-    return str(default) if not value or len(value) == 0 else value
+    return str(default) if cast_default_to_str else default if not value or len(value) == 0 else value
 
 
 def get_simple_logger(
